#
#  ubuntu-dev-tools Launchpad Python modules.
#

SERVICE = "production"
API_VERSION = "devel"
